# au_notebook
[![Build Status](https://travis-ci.org/archivesunleashed/au_notebook.svg?branch=master)](https://travis-ci.org/archivesunleashed/au_notebook)
[![codecov](https://codecov.io/gh/archivesunleashed/au_notebook/branch/master/graph/badge.svg)](https://codecov.io/gh/archivesunleashed/au_notebook)
[![Contribution Guidelines](http://img.shields.io/badge/CONTRIBUTING-Guidelines-blue.svg)](./CONTRIBUTING.md)
[![LICENSE](https://img.shields.io/badge/license-Apache-blue.svg?style=flat-square)](./LICENSE)

## Description

This module is intended for use with Archives Unleashed Cloud derivative data and the [Archives Unleashed Cloud Notebooks](https://raw.githubusercontent.com/archivesunleashed/au_notebook-notebooks).

## Installation

`au_notebook.py` is a single-file Python module that you can drop into your project as needed or you can install globally with:

1. `git clone https://github.com/archivesunleashed/au_notebook.git`
2. `cd au_notebook`
3. `python setup.py install`

or:

`pip install au_notebook`

## Test suite

`python setup.py test`

## Contributing

Please see [contributing guidelines](https://github.com/archivesunleashed/au_notebook/blob/master/CONTRIBUTING.md) for details.
* [Bug reports](https://github.com/archivesunleashed/au_notebook/issues)
* [Pull requests](https://github.com/archivesunleashed/au_notebook/pulls) are welcome on `au_notebook`

## License

Apache 2.0

## Acknowledgments

This work is primarily supported by the [Andrew W. Mellon Foundation](https://uwaterloo.ca/arts/news/multidisciplinary-project-will-help-historians-unlock). Any opinions, findings, and conclusions or recommendations expressed are those of the researchers and do not necessarily reflect the views of the sponsors.
